
This is a plan for next incompatible changes - they are primarily renames.

*   TODO: Introduce `@/data/` dir. And make importable yaml (e.g. from `@/data/`) for server config.

*   TODO: Rename: `arg_type` to `prop_name`

*   TODO: Rename: `relay_demo` to something not cut-off `relay`, at least, both `a` and `r` (something `*ar*`) should be included.
          Something unique yet single word better containing `a` and `r`.

*   TODO: Rename: `relay_server` package to `argrelay_server` (to search `argrelay_server` and find relevant stuff).
*   TODO: Rename: `relay_client` package to `argrelay_client` (to search `argrelay_client` and find relevant stuff).

TODO:
*   Rename all enum items to underscore (e.g. `ServerAction.ProposeArgValues` -> `ServerAction.propse_args_values`).
*   TODO: Consider renaming URL, for example (`_` to `-`, shorten, rethink):
    *   propose_arg_values -> propose-options
    *   describe_line_args -> enum-options
    *   relay_line_args -> invoke-with-options
*   TODO: Rename rest API:
    *   `describe_line_args` -> `query_enum_items` (to match func_id)
    *   `propose_arg_values` -> `complete_line`
    *   `relay_line_args` -> `invoke_line`

*   TODO: Rename `DefaultConfigurator` to `GuiConfigurator`.
*   TODO: Move all GUI config into DefaultConfigurator (including banner).
*   TODO: Move `gui_banner_config` under `DefaultConfigurator`

*   TODO: Rename all `func_id` to be prefixed with `func_id`, for example, `func_id_query_enum_items` -> `func_id_query_enum_items`.
*   TODO: Rename: prefix all `func_id` with `func_id`, for example: `goto_service_func` -> `func_id_goto_service`.

*   TODO: TODO_19_67_22_89: remove `ignored_func_ids_list` - load as `FuncState.fs_unplugged`.

*   TODO: Shorten name `EnvelopeContainer.filled_types_to_values_hidden_by_defaults` to `default_override`-s.

*   TODO: `install_files_procedure` should use 4 config params (instead of 3) - one more is destination dir (not hardcoded `conf`, not hardcoded `exe`, but also `data`, or something else).

*   TODO: Move GUI header and footer to the configurator.
